@@ -547,7 +547,10 @@ perm_test.tram <- function(object, parm = names(coef(object)),
         theta <- theta[names(theta) != parm]
         w <- object$weights
         m0 <- mlt(object$model, data = object$data, weights = object$weights,
-                  offset = off, scale = object$scale, fixed = fx,
+                  offset = off, 
+                  ### NOTE with mlt 1.7-0, disable for the moment
+                  # scale = object$scale, 
+                  fixed = fx,
                   optim = object$optim, theta = theta)
 
         cf <- coef(m1)
@@ -719,7 +722,8 @@ perm_test.tram <- function(object, parm = names(coef(object)),
         if (length(thetafix) > length(theta))
             fx <- thetafix[-names(theta)]
         m0 <- mlt(object$model, data = object$data, weights = object$weights,
-                  offset = off, scale = object$scale, fixed = fx,
+                  offset = off, # scale = object$scale, 
+                  fixed = fx,
                   optim = object$optim, theta = theta)
         
         if (length(list(...)) == 0) {
